@@ -6,8 +6,11 @@
  * https://emeryberger.com
  **/
 
-template <unsigned long Size> class open_addr_hashtable {
-public:
+#include <stdint.h>
+
+template <unsigned long Size>
+class open_addr_hashtable {
+ public:
   open_addr_hashtable() {
     static_assert((Size & (Size - 1UL)) == 0, "Size must be a power of two.");
   }
@@ -22,7 +25,7 @@ public:
   }
 
   void put(void *k, void *v) {
-    auto h = hash1(k) & (Size - 1);
+    auto h = hash1(k) & (Size - 1UL);
     if (payload[h].key == nullptr) {
       payload[h].key = k;
     }
@@ -44,7 +47,7 @@ public:
 
   // @return true iff the element was deleted.
   bool remove(void *k) {
-    auto h = hash1(k);
+    auto h = hash1(k) & (Size - 1UL);
     if (payload[h].key == nullptr) {
       // Not in the hash table.
       return false;
@@ -68,7 +71,7 @@ public:
     }
   }
 
-private:
+ private:
   // Returns -1 if not found.
   int find(void *k) {
     unsigned long h = hash1(k) & (Size - 1UL);
@@ -79,7 +82,7 @@ private:
       return -1;
     }
     while (true) {
-      h = (h + hash2((void *)h)) & (Size - 1UL);
+      h = (h + hash2((void *)h) + 1) & (Size - 1UL);
       if (payload[h].key == k) {
         return h;
       }
